@@ -336,25 +336,7 @@ impl<'a> VisitMut for FieldAccessFolder<'a> {
                     BinExpr {
                         span: DUMMY_SP,
                         left,
-                        op: match op {
-                            op!("=") => unreachable!(),
-
-                            op!("+=") => op!(bin, "+"),
-                            op!("-=") => op!(bin, "-"),
-                            op!("*=") => op!("*"),
-                            op!("/=") => op!("/"),
-                            op!("%=") => op!("%"),
-                            op!("<<=") => op!("<<"),
-                            op!(">>=") => op!(">>"),
-                            op!(">>>=") => op!(">>>"),
-                            op!("|=") => op!("|"),
-                            op!("&=") => op!("&"),
-                            op!("^=") => op!("^"),
-                            op!("**=") => op!("**"),
-                            op!("&&=") => op!("&&"),
-                            op!("||=") => op!("||"),
-                            op!("??=") => op!("??"),
-                        },
+                        op: op.to_update().unwrap(),
                         right: right.take(),
                     }
                     .as_arg()
